# remirepo spec file for php-pecl-zmq
# with SCL compatibility
#
# Fedora spec file for php-pecl-zmq
#
# Copyright (c) 2013-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-zmq}

%bcond_without     tests

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  zmq
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif
%global sources    %{pecl_name}-%{version}
%global _configure ../%{sources}/configure

Summary:        ZeroMQ messaging
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.1.3
Release:        18%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        BSD-3-Clause
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

Patch0:         https://patch-diff.githubusercontent.com/raw/zeromq/php-zmq/pull/216.patch
Patch1:         https://patch-diff.githubusercontent.com/raw/zeromq/php-zmq/pull/222.patch
Patch2:         https://patch-diff.githubusercontent.com/raw/zeromq/php-zmq/pull/228.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  zeromq-devel >= 2.0.7
BuildRequires:  pkgconfig
# BuildRequires:  gdb php-debuginfo php-cli-debuginfo php-debugsource

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

# Version 1.0.7 is the first pecl release
# Fedora/EPEL still provides php-zmq, not php-pecl-zmq
Obsoletes:      %{?scl_prefix}php-%{pecl_name}               < %{version}-99
Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}-99
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}-99
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
ZeroMQ is a software library that lets you quickly design and implement
a fast message-based applications.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b .pr216
%patch -P1 -p1 -b .pr222
%patch -P2 -p1 -b .pr228

if pkg-config libzmq --atleast-version=4
then
# fix new default of MAX_SOCKETS
# Using current version, so this can be checked in next version and removed
# if appropriate. (still not fixed in 1.1.2, maybe later)
sed -i "s/int(1024)/int(1023)/g" tests/032-contextopt.phpt
fi

# Check reported version (phpinfo), as this is often broken
extver=$(sed -n '/#define PHP_ZMQ_VERSION/{s/.* "//;s/".*$//;p}' php_zmq.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{summary} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-zmq \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-zmq \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS \
     install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS \
     install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: upstream test suite for NTS extension
export TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so"
export REPORT_EXIT_STATUS=1
export TEST_PHP_EXECUTABLE=%{__php}
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: upstream test suite for ZTS extension
export TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so"
export TEST_PHP_EXECUTABLE=%{__ztsphp}
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 1.1.3-18
- rebuild for PHP 8.3.0RC1

* Thu Jul 20 2023 Remi Collet <remi@remirepo.net> - 1.1.3-17
- build out of sources tree

* Fri Jun 17 2022 Remi Collet <remi@remirepo.net> - 1.1.3-16
- add patch for PHP 8.2 from https://github.com/zeromq/php-zmq/pull/228

* Wed Nov  3 2021 Remi Collet <remi@remirepo.net> - 1.1.3-15
- add patch for PHP 8.1 from https://github.com/zeromq/php-zmq/pull/222

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.1.3-14
- rebuild for PHP 8.0.0RC1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.1.3-13
- rebuild for PHP 8.0.0beta3

* Mon Aug 24 2020 Remi Collet <remi@remirepo.net> - 1.1.3-12
- add patch for PHP 8 from https://github.com/zeromq/php-zmq/pull/216

* Wed Nov 27 2019 Remi Collet <remi@remirepo.net> - 1.1.3-11
- EL-8 rebuild

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.1.3-10
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.1.3-9
- rebuild for 7.4.0beta1

* Fri Dec 14 2018 Remi Collet <remi@remirepo.net> - 1.1.3-8
- add better patch for 7.3 from
  https://github.com/mkoppanen/php-zmq/pull/195

* Wed Jun 27 2018 Remi Collet <remi@remirepo.net> - 1.1.3-7
- add patch for PHP 7.3 from
  https://github.com/mkoppanen/php-zmq/pull/190

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.1.3-6
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.1.3-5
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.1.3-4
- rebuild for PHP 7.1 new API version

* Wed Aug  3 2016 Remi Collet <remi@fedoraproject.org> - 1.1.3-3
- rebuild against zeromq 4.1 available in EPEL-7

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 1.1.3-2
- adapt for F24

* Mon Feb 01 2016 Remi Collet <remi@fedoraproject.org> - 1.1.3-1
- Update to 1.1.3 (beta)
- add patch to fix build with old GCC (EL-6)
  open https://github.com/mkoppanen/php-zmq/pull/170

* Sun Jan 24 2016 Remi Collet <remi@fedoraproject.org> - 1.1.2-7
- rebuild against zeromq 4 available in EPEL-7

* Tue Jun 23 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-6
- allow build against rh-php56 (as more-php56)

* Sun Mar  1 2015 Remi Collet <remi@fedoraproject.org> - 1.1.2-5
- drop runtime dependency on pear, new scriplets
- don't install test suite
- build against zeromq 4 on F22

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.1.2-4.1
- Fedora 21 SCL mass rebuild

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 1.1.2-4
- improve SCL build

* Thu Apr 17 2014 Remi Collet <remi@fedoraproject.org> - 1.1.2-3
- add numerical prefix to extension configuration file (php 5.6)

* Wed Mar 19 2014 Remi Collet <rcollet@redhat.com> - 1.1.2-2
- allow SCL build

* Mon Nov 25 2013 Remi Collet <remi@fedoraproject.org> - 1.1.2-1
- Update to 1.1.2 (beta)

* Sat Nov 02 2013 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- Update to 1.1.1 (beta)

* Fri Oct 25 2013 Remi Collet <remi@fedoraproject.org> - 1.0.9-1
- Update to 1.0.9 (beta)

* Thu Oct 24 2013 Remi Collet <remi@fedoraproject.org> - 1.0.8-1
- Update to 1.0.8 (beta)
- run upstream test suite during build
- install tests in pecl test_dir

* Thu Oct 24 2013 Remi Collet <remi@fedoraproject.org> - 1.0.7-1
- initial package, version 1.0.7 (beta)
- open https://github.com/mkoppanen/php-zmq/pull/108
  to fix build warnings and include tests

